==> med-fichier_2.3.1.orig.tar.gz: med-2.3.1/src/ci/MEDelementsLire.c <==
/*************************************************************************
* COPYRIGHT (C) 1999 - 2006  EDF R&D
* THIS LIBRARY IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
* IT UNDER THE TERMS OF THE GNU LESSER GENERAL PUBLIC LICENSE 
* AS PUBLISHED BY THE FREE SOFTWARE FOUNDATION; 
* EITHER VERSION 2.1 OF THE LICENSE, OR (AT YOUR OPTION) ANY LATER VERSION.
*  
* THIS LIBRARY IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
* WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
* MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
* LESSER GENERAL PUBLIC LICENSE FOR MORE DETAILS.
*
* YOU SHOULD HAVE RECEIVED A COPY OF THE GNU LESSER GENERAL PUBLIC LICENSE
* ALONG WITH THIS LIBRARY; IF NOT, WRITE TO THE FREE SOFTWARE FOUNDATION,
* INC., 59 TEMPLE PLACE, SUITE 330, BOSTON, MA 02111-1307 USA
*
*************************************************************************/

#include <med.h>
#include <med_config.h>

med_err
MEDelementsLire(med_idt fid,char *maa,med_int mdim,med_int *connectivite,med_mode_switch mode_switch,
	       char *nom,med_booleen *inom,med_int *num,med_booleen *inum,
	       med_int *fam,med_int nele,med_entite_maillage typ_ent, 
	       med_geometrie_element typ_geo,med_connectivite typ_conn)
{
  med_int i;

  /* 
   * Lecture de la connectivite :
   * - On renvoie -1 en cas d'chec
   */
  if (MEDconnLire(fid,maa,mdim,connectivite,mode_switch,0,MED_NOPF,
			 typ_ent,typ_geo,typ_conn) < 0)
    return -1;

  /* 
   * Lecture des noms (presence optionnelle dans un maillage MED)
   */
  if (MEDnomLire(fid,maa,nom,nele,typ_ent,typ_geo) < 0)
    *inom = MED_FAUX;
  else
    *inom = MED_VRAI;

  /* 
   * Lecture des numeros (presence optionnelle dans un maillage MED)
   */
  if (MEDnumLire(fid,maa,num,nele,typ_ent,typ_geo) < 0)
    *inum = MED_FAUX;
  else
    *inum = MED_VRAI;

  /* Lecture des numeros de familles :
   *  - si pas de numeros de familles, cela siginifie qu'ils 
   *    tous egaux a 0
   */
  if (MEDfamLire(fid,maa,fam,nele,typ_ent,typ_geo) < 0)
    for (i=0;i<nele;i++)
      *(fam+i) = 0;
  
  /*
   * Tout s'est bien pass
   */
  return 0;
}

==> med-fichier_2.3.5.orig.tar.gz: med-2.3.5/src/ci/MEDelementsLire.c <==
/*************************************************************************
* COPYRIGHT (C) 1999 - 2007  EDF R&D, CEA/DEN
* THIS LIBRARY IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
* IT UNDER THE TERMS OF THE GNU LESSER GENERAL PUBLIC LICENSE 
* AS PUBLISHED BY THE FREE SOFTWARE FOUNDATION; 
* EITHER VERSION 2.1 OF THE LICENSE, OR (AT YOUR OPTION) ANY LATER VERSION.
*  
* THIS LIBRARY IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
* WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
* MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
* LESSER GENERAL PUBLIC LICENSE FOR MORE DETAILS.
*
* YOU SHOULD HAVE RECEIVED A COPY OF THE GNU LESSER GENERAL PUBLIC LICENSE
* ALONG WITH THIS LIBRARY; IF NOT, WRITE TO THE FREE SOFTWARE FOUNDATION,
* INC., 59 TEMPLE PLACE, SUITE 330, BOSTON, MA 02111-1307 USA
*
*************************************************************************/

#include <med.h>
#include <med_config.h>

med_err
MEDelementsLire(med_idt fid,char *maa,med_int mdim,med_int *connectivite,med_mode_switch mode_switch,
	       char *nom,med_booleen *inom,med_int *num,med_booleen *inum,
	       med_int *fam,med_int nele,med_entite_maillage type_ent, 
	       med_geometrie_element typ_geo,med_connectivite typ_conn)
{
  med_int i;
  med_entite_maillage _type_ent=type_ent;

  if ( type_ent == MED_NOEUD_MAILLE ) _type_ent=MED_NOEUD ;

  /* 
   * Lecture de la connectivite :
   * - On renvoie -1 en cas d'chec
   */
  if (MEDconnLire(fid,maa,mdim,connectivite,mode_switch,0,MED_NOPF,
			 _type_ent,typ_geo,typ_conn) < 0)
    return -1;

  /* 
   * Lecture des noms (presence optionnelle dans un maillage MED)
   */
  if (MEDnomLire(fid,maa,nom,nele,_type_ent,typ_geo) < 0)
    *inom = MED_FAUX;
  else
    *inom = MED_VRAI;

  /* 
   * Lecture des numeros (presence optionnelle dans un maillage MED)
   */
  if (MEDnumLire(fid,maa,num,nele,_type_ent,typ_geo) < 0)
    *inum = MED_FAUX;
  else
    *inum = MED_VRAI;

  /* Lecture des numeros de familles :
   *  - si pas de numeros de familles, cela siginifie qu'ils 
   *    tous egaux a 0
   */
  if (MEDfamLire(fid,maa,fam,nele,_type_ent,typ_geo) < 0)
    for (i=0;i<nele;i++)
      *(fam+i) = 0;
  
  /*
   * Tout s'est bien pass
   */
  return 0;
}
